L = 2;                         % half-length of square centered at the origin
N = 100;                       % N^2 data points for evaluation
[x,y] = meshgrid(-L:1/N:L);
z = x + 1i*y;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% code for plotting a generic function

w = (z.^3-1)./(z.^2+1);        % function to be plotted

% plot immediately to .png file

% imwrite(showcplxm(x,y,w,0.65),'RationalFunction.png','png');

% plot to MATLAB figure file

figure(1)
image(showcplxm(x,y,w,0.65))
title('(z^3-1)/(z^2+1)','fontsize',12)
axis square
tic = 1:N:(1+4*N);
labels = ['-2';'-1';' 0';' 1';' 2'];  % L=2
set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% code for plotting the Julia set - plot immediately to .png file

c = 0.45 + 0.3*1i;               % different values yield different sets
NN = 10;                         % total number of iterates of the map
zn = z;
for k=1:NN
    zn = zn.^2 + c; 
end;
imwrite(showcplxm(x,y,zn,0.65),'JuliaSet.png','png');

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% code for making the polynomial plots demonstrated in class
%

% figure(1)
% w0a = z; w0b = z;
% w1a = z.^2; w1b = sqrt(z);
% w2a = z.^3; w2b = z.^(1/3);
% w3a = z.^4; w3b = z.^(1/4);
% tic = 1:N:(1+4*N);
% labels = ['-2';'-1';' 0';' 1';' 2'];  % L=2
% subplot(2,4,1)
% image(showcplxm(x,y,w0a,0.65))
% title('z','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,5)
% image(showcplxm(x,y,w0b,0.65))
% title('z','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,2)
% image(showcplxm(x,y,w1a,0.65))
% title('z^2','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,6)
% image(showcplxm(x,y,w1b,0.65))
% title('z^{1/2}','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,3)
% image(showcplxm(x,y,w2a,0.65))
% title('z^3','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,7)
% image(showcplxm(x,y,w2b,0.65))
% title('z^{1/3}','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,4)
% image(showcplxm(x,y,w3a,0.65))
% title('z^4','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)
% subplot(2,4,8)
% image(showcplxm(x,y,w3b,0.65))
% title('z^{1/4}','fontsize',12)
% axis square
% set(gca,'xtick',tic,'xticklab',labels,'ytick',tic,'yticklab',labels)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
